@@ -19,6 +19,8 @@
 
 """The main browser widget for QtWebEngine."""
 
+import typing
+
 from PyQt5.QtCore import pyqtSignal, QUrl, PYQT_VERSION
 from PyQt5.QtGui import QPalette
 from PyQt5.QtWidgets import QWidget
@@ -52,10 +54,10 @@ class WebEngineView(QWebEngineView):
                              parent=self)
         self.setPage(page)
 
-        if qtutils.version_check('5.11', compiled=False):
+        if qtutils.version_check('5.11.0', compiled=False, exact=True):
             # Set a PseudoLayout as a WORKAROUND for
             # https://bugreports.qt.io/browse/QTBUG-68224
-            # and other related issues.
+            # and other related issues. (Fixed in Qt 5.11.1)
             sip.delete(self.layout())
             self._layout = miscwidgets.PseudoLayout(self)
 
@@ -66,20 +68,26 @@ class WebEngineView(QWebEngineView):
         However, it sometimes isn't, so we use this as a WORKAROUND for
         https://bugreports.qt.io/browse/QTBUG-68727
 
-        This got introduced in Qt 5.11.0 and fixed in 5.12.0.
+        The above bug got introduced in Qt 5.11.0 and fixed in 5.12.0.
         """
-        if 'lost-focusproxy' not in objects.debug_flags:
-            proxy = self.focusProxy()
-            if proxy is not None:
-                return proxy
+        proxy = self.focusProxy()  # type: typing.Optional[QWidget]
+
+        if 'lost-focusproxy' in objects.debug_flags:
+            proxy = None
+
+        if (proxy is not None or
+                not qtutils.version_check('5.11', compiled=False) or
+                qtutils.version_check('5.12', compiled=False)):
+            return proxy
 
         # We don't want e.g. a QMenu.
         rwhv_class = 'QtWebEngineCore::RenderWidgetHostViewQtDelegateWidget'
         children = [c for c in self.findChildren(QWidget)
                     if c.isVisible() and c.inherits(rwhv_class)]
 
-        log.webview.debug("Found possibly lost focusProxy: {}"
-                          .format(children))
+        if children:
+            log.webview.debug("Found possibly lost focusProxy: {}"
+                              .format(children))
 
         return children[-1] if children else None
 
